#
# spec file for package intel-e1000e
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           intel-e1000e
Summary:        Linux e1000e Base Driver for Intel(R) Network Connection
License:        GPL-2.0+
Group:          System/Kernel
Version:        2.5.4
Release:        1.2
Source0:        e1000e-%{version}.tar.bz2
Source1:        preamble
Url:            http://sourceforge.net/projects/e1000/

BuildRequires:  kernel-source
BuildRequires:  kernel-syms
BuildRequires:  module-init-tools
BuildRequires:  pciutils-ids
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} == 1110
%suse_kernel_module_package kdump ec2 um -p %_sourcedir/preamble
%else
%suse_kernel_module_package kdump um -p %_sourcedir/preamble
%endif

%description
Linux e1000e Base Driver for Intel(R) Network Connection.

%package KMP

Summary:        Linux e1000e Base Driver for Intel(R) Network Connection
Group:          System/Kernel

%description KMP
Linux e1000e Base Driver for Intel(R) Network Connection.

%prep
%setup -n e1000e-%{version}
set -- *
mv src source
mkdir obj

%build
export EXTRA_CFLAGS='-DVERSION=\"%version\"'
for flavor in %flavors_to_build; do
    rm -rf obj/$flavor
    cp -r source obj/$flavor
    make -C /usr/src/linux-obj/%_target_cpu/$flavor modules \
        M=$PWD/obj/$flavor \
        KSRC=/usr/src/linux-obj/%_target_cpu/$flavor
done

%install
export INSTALL_MOD_PATH=$RPM_BUILD_ROOT
export INSTALL_MOD_DIR=updates
for flavor in %flavors_to_build; do
    make -C /usr/src/linux-obj/%_target_cpu/$flavor modules_install \
         M=$PWD/obj/$flavor
done
mkdir -p $RPM_BUILD_ROOT/usr/share/pci.ids.d
install -D -m 644 pci.updates $RPM_BUILD_ROOT/usr/share/pci.ids.d/pci.ids.intel-e1000e-%{version}
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/man7
install -m 644 -D e1000e.7 $RPM_BUILD_ROOT/%{_mandir}/man7
gzip -9nf $RPM_BUILD_ROOT/%{_mandir}/man?/*.?

%clean
rm -rf %{buildroot}

%files 
%defattr(0644,root,root,0755)
%{_mandir}/man7/e1000e.7.gz
/usr/share/pci.ids.d/pci.ids.intel-e1000e-%{version}
%doc COPYING README

%post 
if [ -x /usr/bin/merge-pciids -a -x /usr/bin/perl ]; then
  /usr/bin/merge-pciids
else
  echo "ERROR: merge-pciids or perl not found"
fi

%postun
if [ -x /usr/bin/merge-pciids -a -x /usr/bin/perl ]; then
  /usr/bin/merge-pciids
else
  echo "ERROR: merge-pciids or perl not found"
fi

%changelog
* Fri Feb  7 2014 cs@linux-administrator.com
- 2.5.4
  * Add - ether_addr_equal for use by versions less than 3.5
  * Fix - Semaphore imbalance for 82573 devices
  * Fix - 82579 ethtool offline register tests reg bitmasks
  * Fix - Perform PHY configuration after exiting ULP mode on I218
  * Cleanup - braces {} should be used on all statement arms or none
  * Fix - high CRC error count with 4K RX traffic on 82577/8
  * Fix - overrun of PHY RAR array on 82579
  * Add - Adding error reporting to init_phy_workarounds_pchlan()
  * Fix - Defaulting to continue on ME blocked reset
  * Fix - Hardware Unit Hang
  * Compat - PCI_EXP_LNKCTL_ASPMC introduced in kernel 2.6.29
  * Fix - Use macro instead of digit for defining e1000_rx_desc_packet_split
  * Fix - Remove call for setting MDIO slow mode for I217/I218
  * Fix - I218 ULP updates
  * Fix - Incorrect entries in system log on driver load with cable out
  * Fix - Explicitly set Transmit Control Register to ensure 82574L 100M HDX performance
  * Fix - 82579 sets LPI too early
  * Fix - vlan support for kernels 3.10 and above
  * Fix - for new checkpatch JIFFIES_COMPARISON warning
  * Add - additional I217/I218 PCI IDs
  * Fix - Using InterruptThrottleRate=2 no error message and ITR not set
  * Add - missing branding strings in ich8lan.c
  * Fix - ULP is not supported on LPT MAC with I218 PHY
  * Fix - build warnings on SLES11 SP3
- 2.4.14
  * Add support for I218 "Ultra-Low Power" (ULP) mode enabled in S3/4 and in S0 when Runtime Power Management (RPM) is enabled
  * Fix - do not access MAC registers when RPM suspended
  * Fix - workaround a Tx hang inssue at 100Half on I218
  * Fix - disable ASPM L1 on 82583
  * Cleanup - remove unnecessary workaround for 82578
  * Cleanup/refactor - Runtime Power Management flow
  * Fix - device would repeatedly cycle D0->D3 when RPM enabled and the interface was administratively downed
  * Fix - do not wake from RPM to read PHY status
  * Fix - release mutex lock only if it has been initially acquired on 82574/82583
  * Upstream - commit 73e3dd6b45c4c870fc2641eb04c24e3f12dab1e0 (e1000e: fix numeric overflow in phc settime method)
  * Upstream - commit 80d5c3689b886308247da295a228a54df49a44f6 (net: vlan: prepare for 802.1ad VLAN filtering offload)
  * Upstream - commit f646968f8f7c624587de729115d802372b9063dd (net: vlan: rename NETIF_F_HW_VLAN_ feature flags to NETIF_F_HW_VLAN_CTAG_)
  * Upstream - commit 86a9bad3ab6b6f858fd4443b48738cabbb6d094c (net: vlan: add protocol argument to packet tagging functions)
  * Fix - AMT connection drops after driver unload if large MTU configured
  * Upstream - commit 37287fae7e4506fb0822523587c769783164cdd6 (e1000e: Add missing dma_mapping_error-call in e1000_alloc_jumbo_rx_buffers)
  * Fix - low throughput using 4K jumbo MTU
  * Fix - error checking in initialization flow for I218
  * Fix - ethtool interrogating device takes it out of RPM D3 briefly
  * Refactor/fix system hibernate flow
  * Fix - automatically enable EEE LPI in I217/I218 hardware when in Sx
  * Cleanup - whitespace, indentation and lines exceeding 80 characters
  * Fix - Resolve strict checkpatch USLEEP_RANGE checks
  * Upstream - commit e60b22c5b7e59db09a7c9490b1e132c7e49ae904 (e1000e: fix accessing to suspended device)
  * Upstream - commit 66148babe728f3e00e13c56f6b0ecf325abd80da (e1000e: fix runtime power management transitions)
  * Upstream - commit 4e0855dff094b0d56d6b5b271e0ce7851cc1e063 (e1000e: fix pci-device enable-counter balance)
  * Fix - do not enable EEE on 82579/I217/I218 for speeds in which EEE is not advertised
  * Fix - IEEE MMD register 3.1 at wrong EMI address on 82579
* Fri May 10 2013 cs@linux-administrator.com
- 2.3.2
  * EEE status inaccurately reported by ethtool when connected back-to-back with another e1000e-supported device with EEE
  * Fix compilation issues on SLES11 SP3
  * Upstream commit ffe0b2ff17e1d59d33334767e07e8141de4bd5c8 - e1000e: Use standard #defines for PCIe Capability ASPM fields
  * Upstream commit e792cd916cf74315bddb2c8b2323ef498cd7bfde - e1000e: display a warning message when SmartSpeed works
  * Fix compilation issues on RHEL6.4
  * Cleanup 'unused parameter' compilation warnings
  * Fix DMA unit hang on I218
  * Use kernel-defined MII bit/register definitions
  * Fix performance issue between two 82579 systems connected via a 10Mbps hub
  * Fix link setup code for I217/I218
  * Fix file permissions
  * Upstream commit aaeb6cdfa5c07533c2cd6d2c381374c69f7db9dc - remove init of dev->perm_addr in drivers
  * Upstream commit 9f9a12f8ca79839c948464a37c5b557808278708 - net/intel: remove __dev* attributes
  * Fix LED blink on designs with LEDs driven by cathode
  * Code cleanups
* Sun Feb 10 2013 cs@linux-administrator.com
- 2.2.14
  * enable ECC on i217/i218 and reset the adapter on unrecoverable ECC error
  * checkpatch cleanups
  * change multi-line comment blocks to conform to preferred style in the in-kernel networking code
  * Upstream commit 6e97c170db3878695cb48b5021fffe442ec0aeb0
  - e1000e: Minimum packet size must be 17 bytes
  * Upstream commit 3646f0e5c97703cecfd96cdabb085e78d9b7f680
  - netdev: make pci_error_handlers const
  * Enable timesync (IEEE 1588 PTP) support on 82574/82583/82579/i217/i218
  * remove redundant ethtool statistic counter (rx_long_byte_count, use existing rx_bytes instead)
  * Fix writes of large blocks to EEPROM on 80003es2lan/82571/82572
  * Fix compilation errors on 3.7 and newer kernels
  * Upstream commit 8edc0e624db3756783233e464879eb2e3b904c13
  - e1000e: Change wthresh to 1 to avoid possible Tx stalls
  * Fix adapter resets while transmitting UDP traffic and link drops
  * Performance improvements for jumbo frames on 82566/82567/82577/82578/82579
  * Add support for i218
  * Fix bug determining kernel version when compiling
  * Add ethtool support for EEE
  * Allow EEE in MDI-X mode on 82579/i217/i218
  * Fix bug in ethtool offline register test on i217/i218
  * Fix 82571 serdes link issue
  * Upstream commit 4e8186b68fb944ad9e7fd4080cd8bd8f10eb7cbd
  - e1000e: implement MDI/MDI-X control
  * Upstream commit f0c5dadff3fbda77a65b8577fee437c3d771233d
  - e1000e: fix panic while dumping packets on Tx hang with IOMMU
  * Upstream commit 49ce9c2cda18f62b13055dc715e7b514157c2da8
  - drivers/net/ethernet: Fix (nearly-)kernel-doc comments for various functions
  * Upstream commit 7b1115e017569219eccbcad2bc48b81e6b98df29
  - e1000e: advertise transmit time stamping
* Sun Sep 23 2012 cs@linux-administrator.com
- 2.1.4
  * 82577/8/9 - increase MSE threshold to avoid unexpected link drop
  * 82571 Tx Data Corruption during Tx hang recovery
  * 82571 serdes link instability if auto-negotiation fails - RH bug #771366
  * 82571 serdes link issue - RH #840642 and SF #346
  * Enable EEE on 82579/i217 only when link partner is capable of EEE
  * DoS while TSO enabled caused by link partner with small MSS
  * Program the correct register for ITR when using MSI-X on 82574
  * Test that 82577/82578/82579/i217 PHY is accessible
    otherwise driver can fail to load
  * remove use of the unnecessary IP payload checksum to allow concurrent
    use of receive hashing offload and jumbo frames
  * implement mdi-mdix setting supporton 82577/9
  * use more informative logging macros when netdev not yet registered
  * compile failure on 2.6.37+ kernels with CFLAGS_EXTRA="-DE1000E_NO_NAPI"
  * bug in bit shift when setting SMBus frequency on i217
  * Upstream commit 80be3129d7152fe73b7d5db4595e2f4267497f24
  - e1000e: add transmit timestamping support
  * Upstream commit 59aed95263bdd0e2b48eb9be5a94346d2d4abf90
  - e1000e: Remove special case for 82573/82574 ASPM L1 disablement
  * Upstream commit d4a4206ebbaf48b55803a7eb34e330530d83a889
  - e1000e: Disable ASPM L1 on 82574
  * Upstream commit 727c356f4d799b53f94cf8fe43e19d64482348c7
  - e1000e: Fix default interrupt throttle rate not set in NIC HW
  * Upstream commit 569a3aff70e880588fe4b3f1622ac60abbeb4a28
  - e1000e: MSI interrupt test failed, using legacy interrupt
* Tue Jun 19 2012 jweberhofer@weberhofer.at
- 2.0.0.1
  * Add preliminary basic support for i217 available on some platforms
    with the Lynx Point Platform Controller Hub (PCH) chipset from Intel
  * Upstream commit b3f4d5990bfc8b060e5010c1464789fca1f4c5b4 - intel: make
    wired ethernet driver message level consistent
  * fix and commonize 82577/8/9 and i217 PHY init/resume work
  * fix LPLU in non-D0a on 82577/8
  * cleanup code including new checkpatch warnings, boolean expressions and
    whitespace issues
  * Upstream commit 4679026d783eb5ac90247bc466d66b817b213abf
  - net: remove the second argument of k[un]map_atomic()
  * Upstream commit cf955e6c96cb9af2dce7093a8e3a5e808555c8a4
  - e1000e: Support RXALL feature flag.
  * Upstream commit 943146de22d3658de26d94512beae7223282ed1c
  - e1000e: Support sending custom Ethernet CRC
  * Upstream commit 0184039a4b6727d6efd545919c773ef141090ae7
  - e1000e: Support RXFCS feature flag
  * Upstream commit 3f0cfa3bc11e7f00c9994e0f469cbc0e7da7b00c
  - e1000e: Support for byte queue limits
  * Fix WARN_ON when resetting device while it is already being reset
  * Fix 82577/8 autoneg'ing to 10Mbps instead of 1000Mbps in D0
  * WoL fix for 82577/8 * Adjust delay after LANPHYPC toggle for 82579
* Sat Apr 21 2012 jweberhofer@weberhofer.at
- 1.11.3
  * Enabled DMA Burst Mode on 82574 by default for performance gain with small packets.
  * Fixed issue with 82574/82583 sometimes not auto-negotiating gigabit link.
  * Disabled IPv6 extension header parsing because some malformed IPv6 headers can hang the Rx.
  * Disabled IBIST slave mode (far-end loopback) on 80003ES2LAN during reset to ensure the mode does not accidentally become enabled.
- 1.10.6
  * Fix kernel oops caused by concurrent reset and close of device (SourceForge bug tracker 3486658)
  * Code cleanup - whitespace, indentation, use true/false for booleans,
    use function pointers rather instead of API calls, checkpatch warnings,
    sparse warnings, remove unnecessary parentheses, duplicate code, use
    logical operators instead of comparing to true/false, remove unnecessary
    return from void functions, goto coding style
  * Upstream commit 5f4a780ddd453c4918555fed9d9c5f2d455a087d - e1000e: hitting BUG_ON() from napi_enable
  * Fix compilation issues when compiled with W=1
  * Upstream commit 9e2d7657e2a8fb40f732563dffb05151ea2d7e01 - e1000e: cleanup - check return values consistently
  * Upstream commit f23efdff77bbc1207255ccebe04771970604bbd9 - e1000e: cleanup e1000_set_phys_id
  * Upstream commit 0e15df490eef6f5080b84533dcd3068a78122768 - e1000e: minor whitespace and indentation cleanup
  * Upstream commit fe1e980f24697edb7d4e17cd74bbeae4a0388525 - e1000e: remove unnecessary returns from void functions
  * Upstream commit 75ce15327030128d713079d1f5e23cbe7af532f6 - e1000e: cleanup: rename goto labels to be more meaningful
  * Upstream commit 5015e53a4cf0c88977120faede7eb02b0459d90e - e1000e: cleanup goto statements to exit points without common work
  * Fix a possible device hang on 82579 during stress
  * Upstream commit c85c21ad1fe18daf26bfe8684df974d88cec50b7 - e1000e: Need to include vmalloc.h
  * Upstream commit 8e586137e6b63af1e881b328466ab5ffbe562510 - net: make vlan ndo_vlan_rx_[add/kill]_vid return error value
  * Upstream commit 09357b00255c233705b1cf6d76a8d147340545b8 - e1000e: Avoid wrong check on TX hang
  * WoL fixes for 82577/8/9
  * Fix for 82579 failure to read PHY register during init
  * Fix packet drop issue on 82579
* Wed Jan 25 2012 jweberhofer@weberhofer.at
- 1.9.5
  * Fix compile issues on Fedora 15 kernel
  * Cleanup whitespace and other checkpatch warnings/errors
  * conditionally restart autoneg on 82577/8/9 when setting LPLU state
  * Upstream: e1000e: Convert printks to pr_<level> (commit ef456f85)
  * Upstream: Sweep the last of the active .get_drvinfo floors under ethernet/
    (commit 612a94d6)
  * increase Rx PBA to prevent dropping received packets on 82566/82567
  * Upstream: net: introduce and use netdev_features_t for device features sets
    commit (c8f44aff)
  * ICHx/PCHx LOMs should use LPLU setting in NVM when going to Sx
  * update workaround for 82579 intermittently disabled during S0->Sx
  * Upstream: drivers/net: Add module.h to drivers who were implicitly using it
    (commit 9d9779e723a5d23b94abbe5bb7d1197921f6f3dd)
  * Fix build warnings with CFLAGS_EXTRA=-DE1000E_NO_NAPI
  * disable Early Receive DMA on ICH LOMs
  * Upstream: net: add skb frag size accessors (commit 9e903e085262ffbf1fc44a17ac06058aca03524a)
  * Upstream: intel: convert to SKB paged frag API (commit
    877749bf3f2f7a517ae74cd2c2fa4eed7aa9b51d)
  * Upstream: PM QoS: Move and rename the implementation files (commit
    e8db0be1245de16a6cc6365506abc392c3c212d4)
  * Upstream: e1000e: convert to stats64 (commit
    67fd4fcb78a7ced369a6bd8a131ec8c65ebd2bbb)
  * Upstream: net: Remove unnecessary driver assignments of ethtool_ringparam
    fields to zero (commit 8b0c11679fd37522d8d34a76101319a085d80912)
  * Upstream: e1000e: fix skb truesize underestimation (commit
    98a045d7e4a59db0865a59eea2140fe36bc7c220)
  * Upstream: e1000e: convert to real ndo_set_rx_mode (commit
    ef9b965a1c4ebd0f0ee961dbc328e1222dc8f487)
  * 82574/82583 Tx hang workaround
  * use hardware default values for Transmit Control register
  * Upstream: e1000e: locking bug introduced by commit 67fd4fcb (commit
    a90b412cb8c7ccc1689f9ea130883d00a1f0a5bb)
  * remove custom setting of TIPG for 8000es2lan
  * use default settings for Tx Inter Packet Gap timer
  * workaround WoL failures on some ICH8 LOMs
  * 82579: workaround for link drop issue
  * always set transmit descriptor control registers the same
  * re-factor ethtool get/set ring parameter
  * pass pointer to ring struct instead of adapter struct
  * default IntMode based on kernel config & available hardware support
  * convert head,	tail and itr_register offsets to __iomem pointers
  * remove MSI-X code not wrapped with CONFIG_E1000E_SEPARATE_TX_HANDLER to sync
    with upstream driver
  * re-enable alternate MAC address for all devices which support it
  * Upstream: e1000e: convert to netdev features/hw_features API (commit
    dc221294719ae0f28cc260cc37edd439161088a9)
  * cleanup Rx checksum offload code
  * Upstream: net: remove use of ndo_set_multicast_list in drivers (commit afc4b13df143122f99a0eb10bfefb216c2806de0)
  * workaround Rx crc errors with jumbo frame stress on 82578
  * add Receive Packet Steering (RPS) support
* Thu Oct 27 2011 jweberhofer@weberhofer.at
- 1.6.3
  * Fix for rx_no_buffer_count increments when RPS is enabled
- 1.6.2
  * 82578DM: Fix for WOL fails after several reboots.
  * Enable Rx hash use by stack for 1Gig.
  * Convert to new VLAN model.
  * 82577: rx_crc_errors wirh jumbo frames and SSC enabled.
- 1.5.1
  * Do not support Alternate MAC Address if NVM word 0x37 has a value of 0x0000
  * Change workaround for Tx hang in previous release to do same for Rx side
  * Two workarounds for missed packets on 82579 in 100half
  * Perform write flush after most registers writes that are followed by a delay
  * Fix for panic on RHEL5.7 with vlan code
- 1.4.4
  * 82579: Fix for Tx Hang on FTS ME Platform
  * 82571: Add device id to fix for alternate MAC address feature
  * Upstream commits: 25db0338, 70739497 and 14ad2513, Change ethtool interfaces to use ethtool_cmd_speed[_set] API.
  * Convert use of receive descriptors from legacy to extended format
    to allow future enablement of advanced features such as timesync and RPS.
- 1.3.17
  * Fixed an occassional panic on RHEL5.4 and newer when suspending/hibernating the adapter.
  * 82577/8 clear Host Wakeup bit without touching PHY registers on page 800 (necessary as a workaround)
  * Upstream: PM: Remove CONFIG_PM_OPS (commit aa338601)
  * Upstream: e1000e: If ASPM L0s needs to be disabled, do it prior to enabling device (commit 78cd29d5)
  * Use new ethtool set_phys_id entry point
  * Do not set blink_led function pointer incorrectly for 82574/82583
  * Add ability to access multiple PHY registers on the same page while holding a lock without having to set the page for every access. Use this method in a number of places for ICH/PCH adapters.
  * 82579: Fixed an issue where the adapter could become disabled during Sx stress testing. Renamed e1000_disable_gig_wol() to better reflect what it does.
  * Upstream: e1000e: use dev_kfree_skb_irq() instead of dev_kfree_skb() (commit ef5ab89c)
  * Upstream: net: use pci_dev->revision, again (commit ff938e43)
  * Convert msec_delay's less than 20msec to usleep_range as described in ./Documentation/timers/timers-howto.txt in the kernel source tree
  * Refactor fix in previous release that fixed an issue where the adapter could reset unnecessarily when ethtool -r is done while passing traffic
  * Report PCIe link speed during driver load in GT/s, not GB/s
  * Do not report driver supports Wake-on-ARP since it does not
  * Various code cleanups
  * ICH/PCH: release mutex but not sw/fw/hw semaphore (swflag) after hw reset; log debug message if swflag is released unexpectedly
  * 80003es2lan: fixed an issue where the ESB2 LAN interface could become non- functional and possibly identify it's MAC address incorectly to switches when setting up the switching tables
* Mon Feb 14 2011 opendevel@weberhofer.at
- 1.3.10a
- 82579: Don't allow jumbo frames to be configured when MACsec enabled
  in EEPROM
- 82567LM-3/82567LF-3/82567V-4: use MAC-based WoL instead of PHY-based
  WoL. The unsupported PHY-based WoL was inadvertently enabled when
  support was added for 82577/82578, and could cause problems in Sx
  states.
- Do not increment tx_timeout statistic when normally resetting the
  adapter when there is outstanding transmit work.
- Do not run any scheduled tasks when adapter is going down, otherwise a
  deadlock may occur.
- Miscellaneous comment/printk typos
- 82579: Update EEE timer value to prevent link from dropping
- Various minor changes based on static analysis of the driver code
- Prevent adapter from being reset when passing traffic and re-starting
  auto-negotiation via 'ethtool -r ethX'
- Upstream: don't use flush_scheduled_work (commit 23f333a2)
- Upstream: Fix drivers advertising HW_CSUM feature to use csum_start
  (commit 0d0b1672)
- Upstream: fix double initialization in blink path (commit 9633e63b)
- Upstream: Use default implementation of ethtool_ops::get_link where
  possible (commit ed4ba4b5)
- Upstream: add netpoll support for MSI/MSI-X IRQ modes (commit
  147b2c8c)
- Use kmemdup rather than duplicating its implementation
- Fix sparse warnings
- 82579: fails ethtool online diagnostic link test when connected to
  certain switches. Extend the timeout to acquire link to 5 seconds and
  document the issue.
- Use ether_crc_le rather than duplicating its implementation
- 8257x: do not ignore return from e1000_get_phy_id)82571()
- 82571: PHY_CONTROL bit 11 (power down) cleared when hardware is reset.
  Power down the PHY during reset when the interface is down, not running
  ethtool diagnostics and WoL is disabled.
- Use vzalloc instead of vmalloc/memset
- Rename files to match closer to upstream driver filenames
- Fix non-whitespace checkpatch issues
- Fix compile warnings with new gcc 4.6
- Declare various tables as static const to reduce data and overall
  object size
- 82574: requires its own set_d[0|3]_lplu_state functions
- Fix compilation errors on SuSE SLES10 PPC
- Fix spec file to allow rpm builds on newer OSV
- Upstream: avoid some skb->ip_summed initializations (commit bc8acf2c)
- Upstream: return operator cleanup (commit 807540ba)
- Upstream: set NETIF_F_HIGHDMA for VLAN feature flags (commit 7b872a55)
- Upstream: Remove address use from assignments of function pointers
  (commit c061b18d)
- Upstream: Don't check for vlan group before vlan_tx_tag_present
  (commit eab6d18d)
- Upstream: Rename VLAN_GROUP_ARRAY_LEN to VLAN_N_VID (commit b738127d)
- Upstream: Simplify MSI interrupt testing (commit 068e8a30)
- 82574: do not disable ASPM L1
- 82571/82572/80003ES2LAN: use hardware writeback batching to improve
  bus utilization and removes partial writes on certain systems.
* Thu Nov 25 2010 opendevel@weberhofer.at
- 1.2.20 Version upgrade
* Tue Apr 20 2010 linux@weberhofer.at
- update to build 1.1.2.1a
* Tue Sep  8 2009 sbahling@suse.de
- initial build of 1.0.2.5
